=======
Credits
=======

Development Lead
----------------

* Håvard Berland <havb@equinor.com>
* Anders Fredrik Kjær <akia@equinor.com>
* Hans Kallekleiv <hakal@equinor.com>
* Jan C. Rivenæs <jriv@equinor.com>
* Fahad Dilib <fdil@equinor.com>

Contributors
------------

None yet. Why not be the first?
